@@ -1,4 +1,6 @@
 import os
+
+import yaml
 from simple_logger.logger import get_logger
 import json
 import click
@@ -6,6 +8,13 @@ import click
 LOGGER = get_logger(name=__name__)
 
 
+def get_util_config(util_name, config_file_path):
+    if os.path.exists(config_file_path):
+        with open(config_file_path) as _file:
+            return yaml.safe_load(_file).get(util_name, {})
+    return {}
+
+
 # Reference: https://gist.github.com/welel/9cf860dd3f4d3e09f9b4305878b3a04e
 class ListParamType(click.ParamType):
     """Represents the list type of a CLI parameter.
